@@ -536,6 +536,30 @@ ptyxis_client_spawn_cb (GObject      *object,
                                   g_object_ref (task));
 }
 
+static const char *
+maybe_extract_path_from_uri (GFile      *file,
+                             const char *original_uri)
+{
+  if (file == NULL)
+    return NULL;
+
+  /*
+   * Special-case handling for URIs which are file:// but GVFS
+   * translated them into something like `sftp://.../` even though
+   * they are local on disk (`/run/user/1000/gvfs/.../`).
+   */
+  if (!g_file_is_native (file))
+    {
+      if (original_uri == NULL)
+        return NULL;
+
+      if (!(original_uri[0] != '/' || g_str_has_prefix (original_uri, "file://")))
+        return NULL;
+    }
+
+  return g_file_peek_path (file);
+}
+
 void
 ptyxis_client_spawn_async (PtyxisClient        *self,
                            PtyxisIpcContainer  *container,
@@ -645,7 +669,7 @@ ptyxis_client_spawn_async (PtyxisClient        *self,
       arg0 = g_strdup ("");
       g_strv_builder_add (argv_builder, "sh");
       g_strv_builder_add (argv_builder, "-c");
-      g_strv_builder_add (argv_builder, "$(getent passwd $(whoami) | cut -d : -f 7)");
+      g_strv_builder_add (argv_builder, "if [ -x \"$(getent passwd $(whoami) | cut -d : -f 7)\" ]; then exec $(getent passwd $(whoami) | cut -d : -f 7); else exec sh; fi");
     }
 
   if (arg0 != NULL &&
@@ -678,8 +702,7 @@ ptyxis_client_spawn_async (PtyxisClient        *self,
           G_GNUC_FALLTHROUGH;
 
         case PTYXIS_PRESERVE_DIRECTORY_ALWAYS:
-          if (last_directory != NULL && g_file_is_native (last_directory))
-            cwd = g_file_peek_path (last_directory);
+          cwd = maybe_extract_path_from_uri (last_directory, last_working_directory_uri);
           break;
 
         default:
