@@ -34,6 +34,12 @@
 #include "ptyxis-shortcut-row.h"
 #include "ptyxis-util.h"
 
+/* This will not transition to AdwDialog until there is a way for
+ * toplevel windows _with_ transient-for set to maintain window
+ * group ordering.
+ */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 struct _PtyxisPreferencesWindow
 {
   AdwPreferencesWindow  parent_instance;
@@ -113,7 +119,7 @@ struct _PtyxisPreferencesWindow
   PtyxisShortcutRow    *shortcut_zoom_in;
   PtyxisShortcutRow    *shortcut_zoom_one;
   PtyxisShortcutRow    *shortcut_zoom_out;
-  GtkLinkButton        *show_more;
+  AdwButtonContent     *show_more_palettes;
   AdwComboRow          *tab_position;
   GListModel           *tab_positions;
   AdwComboRow          *text_blink_mode;
@@ -265,6 +271,30 @@ ptyxis_preferences_window_add_profile (GtkWidget  *widget,
   ptyxis_application_add_profile (PTYXIS_APPLICATION_DEFAULT, profile);
 }
 
+static void
+ptyxis_preferences_window_add_toast (GtkWidget  *widget,
+                                     const char *action_name,
+                                     GVariant   *param)
+{
+  PtyxisPreferencesWindow *self = PTYXIS_PREFERENCES_WINDOW (widget);
+  AdwToast *toast;
+  const char *title;
+  guint timeout;
+
+  if (!g_variant_lookup (param, "title", "&s", &title))
+    title = "";
+
+  if (!g_variant_lookup (param, "timeout", "u", &timeout))
+    timeout = 0;
+
+  toast = g_object_new (ADW_TYPE_TOAST,
+                        "title", title,
+                        "timeout", timeout,
+                        NULL);
+
+  adw_preferences_window_add_toast (ADW_PREFERENCES_WINDOW (self), toast);
+}
+
 static void
 ptyxis_preferences_window_profile_row_activated_cb (PtyxisPreferencesWindow *self,
                                                     PtyxisProfileRow        *row)
@@ -281,17 +311,23 @@ ptyxis_preferences_window_profile_row_activated_cb (PtyxisPreferencesWindow *sel
 
 static gboolean
 ptyxis_preferences_window_show_all_cb (PtyxisPreferencesWindow *self,
-                                       GtkLinkButton           *button)
+                                       GtkButton               *button)
 {
   g_assert (PTYXIS_IS_PREFERENCES_WINDOW (self));
-  g_assert (GTK_IS_LINK_BUTTON (button));
+  g_assert (GTK_IS_BUTTON (button));
 
   self->filter_show_more = !self->filter_show_more;
 
   if (self->filter_show_more)
-    gtk_button_set_label (GTK_BUTTON (self->show_more), _("Show fewer…"));
+    {
+      adw_button_content_set_label (self->show_more_palettes, _("Show Fewer Palettes"));
+      adw_button_content_set_icon_name (self->show_more_palettes, "up-small-symbolic");
+    }
   else
-    gtk_button_set_label (GTK_BUTTON (self->show_more), _("Show more…"));
+    {
+      adw_button_content_set_label (self->show_more_palettes, _("Show All Palettes"));
+      adw_button_content_set_icon_name (self->show_more_palettes, "down-small-symbolic");
+    }
 
   gtk_filter_changed (GTK_FILTER (self->filter), GTK_FILTER_CHANGE_DIFFERENT);
 
@@ -990,7 +1026,7 @@ ptyxis_preferences_window_class_init (PtyxisPreferencesWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_zoom_in);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_zoom_one);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_zoom_out);
-  gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, show_more);
+  gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, show_more_palettes);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, tab_position);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, tab_positions);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, text_blink_mode);
@@ -1009,6 +1045,10 @@ ptyxis_preferences_window_class_init (PtyxisPreferencesWindowClass *klass)
                                    "settings.select-custom-font",
                                    NULL,
                                    ptyxis_preferences_window_select_custom_font);
+  gtk_widget_class_install_action (widget_class,
+                                   "toast.add",
+                                   NULL,
+                                   ptyxis_preferences_window_add_toast);
 
   g_type_ensure (PTYXIS_TYPE_PREFERENCES_LIST_ITEM);
   g_type_ensure (PTYXIS_TYPE_PROFILE_EDITOR);
@@ -1090,3 +1130,5 @@ ptyxis_preferences_window_edit_shortcuts (PtyxisPreferencesWindow *self)
   adw_preferences_window_pop_subpage (ADW_PREFERENCES_WINDOW (self));
   adw_preferences_window_set_visible_page_name (ADW_PREFERENCES_WINDOW (self), "shortcuts");
 }
+
+G_GNUC_END_IGNORE_DEPRECATIONS
