@@ -396,7 +396,7 @@ ptyxis_tab_respawn (PtyxisTab *self)
   g_autoptr(VtePty) new_pty = NULL;
   PtyxisApplication *app;
   const char *profile_uuid;
-  const char *cwd;
+  const char *cwd_uri;
   VtePty *pty;
 
   g_assert (PTYXIS_IS_TAB (self));
@@ -458,14 +458,14 @@ ptyxis_tab_respawn (PtyxisTab *self)
       pty = new_pty;
     }
 
-  cwd = self->previous_working_directory_uri;
+  cwd_uri = self->previous_working_directory_uri;
   if (self->initial_working_directory_uri)
-    cwd = self->initial_working_directory_uri;
+    cwd_uri = self->initial_working_directory_uri;
 
   ptyxis_application_spawn_async (PTYXIS_APPLICATION_DEFAULT,
                                   container,
                                   self->profile,
-                                  cwd,
+                                  cwd_uri,
                                   pty,
                                   (const char * const *)self->command,
                                   NULL,
@@ -592,9 +592,8 @@ ptyxis_tab_bell_cb (PtyxisTab      *self,
 static PtyxisIpcContainer *
 ptyxis_tab_discover_container (PtyxisTab *self)
 {
-  VteTerminal *terminal = VTE_TERMINAL (self->terminal);
-  const char *current_container_name = vte_terminal_get_current_container_name (terminal);
-  const char *current_container_runtime = vte_terminal_get_current_container_runtime (terminal);
+  const char *current_container_name = ptyxis_terminal_get_current_container_name (self->terminal);
+  const char *current_container_runtime = ptyxis_terminal_get_current_container_runtime (self->terminal);
 
   return ptyxis_application_find_container_by_name (PTYXIS_APPLICATION_DEFAULT,
                                                     current_container_runtime,
@@ -638,23 +637,33 @@ ptyxis_tab_dup_icon (PtyxisTab *self)
 }
 
 static void
-ptyxis_tab_notify_palette_cb (PtyxisTab      *self,
-                              GParamSpec     *pspec,
-                              PtyxisTerminal *terminal)
+ptyxis_tab_invalidate_thumbnail (PtyxisTab *self)
 {
   GtkWidget *view;
   AdwTabPage *page;
 
   g_assert (PTYXIS_IS_TAB (self));
-  g_assert (PTYXIS_IS_TERMINAL (terminal));
 
   g_clear_object (&self->cached_texture);
 
+  gtk_widget_queue_draw (GTK_WIDGET (self));
+
   if ((view = gtk_widget_get_ancestor (GTK_WIDGET (self), ADW_TYPE_TAB_VIEW)) &&
       (page = adw_tab_view_get_page (ADW_TAB_VIEW (view), GTK_WIDGET (self))))
     adw_tab_page_invalidate_thumbnail (page);
 }
 
+static void
+ptyxis_tab_notify_palette_cb (PtyxisTab      *self,
+                              GParamSpec     *pspec,
+                              PtyxisTerminal *terminal)
+{
+  g_assert (PTYXIS_IS_TAB (self));
+  g_assert (PTYXIS_IS_TERMINAL (terminal));
+
+  ptyxis_tab_invalidate_thumbnail (self);
+}
+
 static void
 ptyxis_tab_update_scrollbar_policy (PtyxisTab *self)
 {
@@ -697,6 +706,20 @@ ptyxis_tab_update_scrollbar_policy (PtyxisTab *self)
     }
 }
 
+static void
+ptyxis_tab_update_padding_cb (PtyxisTab      *self,
+                              GParamSpec     *pspec,
+                              PtyxisSettings *settings)
+{
+  g_assert (PTYXIS_IS_TAB (self));
+  g_assert (PTYXIS_IS_SETTINGS (settings));
+
+  if (ptyxis_settings_get_disable_padding (settings))
+    gtk_widget_remove_css_class (GTK_WIDGET (self->terminal), "padded");
+  else
+    gtk_widget_add_css_class (GTK_WIDGET (self->terminal), "padded");
+}
+
 static void
 ptyxis_tab_constructed (GObject *object)
 {
@@ -725,6 +748,13 @@ ptyxis_tab_constructed (GObject *object)
                           self->terminal, "text-blink-mode",
                           G_BINDING_SYNC_CREATE);
 
+  g_signal_connect_object (settings,
+                           "notify::disable-padding",
+                           G_CALLBACK (ptyxis_tab_update_padding_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
+  ptyxis_tab_update_padding_cb (self, NULL, settings);
+
   g_signal_connect_object (PTYXIS_APPLICATION_DEFAULT,
                            "notify::overlay-scrollbars",
                            G_CALLBACK (ptyxis_tab_update_scrollbar_policy),
@@ -1157,6 +1187,15 @@ ptyxis_tab_init (PtyxisTab *self)
                     G_CALLBACK (on_scroll_end_cb),
                     self);
   gtk_widget_add_controller (GTK_WIDGET (self), controller);
+
+  /* Ensure we redraw when the dark-mode changes so that if the user
+   * goes to the tab-overview all the tabs look correct.
+   */
+  g_signal_connect_object (adw_style_manager_get_default (),
+                           "notify::dark",
+                           G_CALLBACK (ptyxis_tab_invalidate_thumbnail),
+                           self,
+                           G_CONNECT_SWAPPED);
 }
 
 PtyxisTab *
@@ -1219,7 +1258,11 @@ ptyxis_tab_dup_title (PtyxisTab *self)
 
   gstr = g_string_new (self->title_prefix);
 
-  if ((window_title = vte_terminal_get_window_title (VTE_TERMINAL (self->terminal))) && window_title[0])
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  window_title = vte_terminal_get_window_title (VTE_TERMINAL (self->terminal));
+  G_GNUC_END_IGNORE_DEPRECATIONS
+
+  if (window_title && window_title[0])
     g_string_append (gstr, window_title);
   else if (self->command != NULL && self->command[0] != NULL)
     g_string_append (gstr, self->command[0]);
@@ -1261,28 +1304,28 @@ ptyxis_tab_collapse_uri (const char *uri)
 char *
 ptyxis_tab_dup_subtitle (PtyxisTab *self)
 {
-  const char *current_directory_uri;
-  const char *current_file_uri;
+  g_autofree char *current_directory_uri = NULL;
+  g_autofree char *current_file_uri = NULL;
 
   g_return_val_if_fail (PTYXIS_IS_TAB (self), NULL);
 
-  current_file_uri = vte_terminal_get_current_file_uri (VTE_TERMINAL (self->terminal));
+  current_file_uri = ptyxis_terminal_dup_current_file_uri (self->terminal);
   if (current_file_uri != NULL && current_file_uri[0] != 0)
     return ptyxis_tab_collapse_uri (current_file_uri);
 
-  current_directory_uri = vte_terminal_get_current_directory_uri (VTE_TERMINAL (self->terminal));
+  current_directory_uri = ptyxis_terminal_dup_current_directory_uri (self->terminal);
   if (current_directory_uri != NULL && current_directory_uri[0] != 0)
     return ptyxis_tab_collapse_uri (current_directory_uri);
 
   return NULL;
 }
 
-const char *
-ptyxis_tab_get_current_directory_uri (PtyxisTab *self)
+char *
+ptyxis_tab_dup_current_directory_uri (PtyxisTab *self)
 {
   g_return_val_if_fail (PTYXIS_IS_TAB (self), NULL);
 
-  return vte_terminal_get_current_directory_uri (VTE_TERMINAL (self->terminal));
+  return ptyxis_terminal_dup_current_directory_uri (self->terminal);
 }
 
 void
@@ -1517,8 +1560,8 @@ ptyxis_tab_dup_container (PtyxisTab *self)
 
   g_return_val_if_fail (PTYXIS_IS_TAB (self), NULL);
 
-  if ((runtime = vte_terminal_get_current_container_runtime (VTE_TERMINAL (self->terminal))) &&
-      (name = vte_terminal_get_current_container_name (VTE_TERMINAL (self->terminal))))
+  if ((runtime = ptyxis_terminal_get_current_container_runtime (self->terminal)) &&
+      (name = ptyxis_terminal_get_current_container_name (self->terminal)))
     container = ptyxis_application_find_container_by_name (PTYXIS_APPLICATION_DEFAULT, runtime, name);
 
   if (container == NULL)
@@ -1845,3 +1888,32 @@ ptyxis_tab_open_uri (PtyxisTab  *self,
   G_GNUC_END_IGNORE_DEPRECATIONS
 }
 #endif
+
+char *
+ptyxis_tab_query_working_directory_from_agent (PtyxisTab *self)
+{
+  g_autofree char *path = NULL;
+  g_autoptr(GUnixFDList) fd_list = NULL;
+  VtePty *pty;
+  int pty_fd;
+  int handle;
+
+  g_return_val_if_fail (PTYXIS_IS_TAB (self), NULL);
+
+  if (self->process == NULL)
+    return NULL;
+
+  pty = vte_terminal_get_pty (VTE_TERMINAL (self->terminal));
+  pty_fd = vte_pty_get_fd (pty);
+  fd_list = g_unix_fd_list_new ();
+  handle = g_unix_fd_list_append (fd_list, pty_fd, NULL);
+
+  if (ptyxis_ipc_process_call_get_working_directory_sync (self->process,
+                                                          g_variant_new_handle (handle),
+                                                          fd_list,
+                                                          &path,
+                                                          NULL, NULL, NULL))
+    return g_steal_pointer (&path);
+
+  return NULL;
+}
